// Persistence of Vision Ray Tracer Scene Description File
// File: templ_1.pov
// Vers: 3
// Desc: This file demonstrates the use of Textures2POV with a template file.
//       You have to set the "Number of samples" in Textures2POV to 27.
// Date: 11/16/1997
// Auth: Friedemann Schmidt, friedemann@stones.com

#declare Stack = union {
  box { -1, 1 }
  cylinder { -y, y, 1 translate 2*y}
  sphere{<0, 4, 0>, 1}
}

#declare ScenePos = -10000;
#declare LabelMaxWidth = 2.9;

#declare i = 1;
#while (i <= 27 & TextureNr <= TexturesCount)

  // ********* #include TextureView 27 4:3 - this line will be replaced by TextureView

  #declare LabelText1 = TextureFile
  #declare LabelText2 = TextureName

  #declare X = -12+mod(i-1, 9)*3;
  #declare Y = 10.5 - int((i-1)/9)*7;
  object {
    Stack
    #if (IsMaterial = true)
      material { Texture }
    #else
      texture { Texture }
    #end
    translate <X, Y, 0> + ScenePos
    hollow
  }

  #declare LabelFontScale = 1;
  #declare LabelWidth = max(strlen(LabelText1)*0.6*LabelFontScale, strlen(LabelText2)*0.6*LabelFontScale);
  #if (LabelWidth > LabelMaxWidth)
    #declare LabelFontScale = (LabelMaxWidth)/(LabelWidth)*LabelFontScale;
    #declare LabelWidth = LabelMaxWidth;
  #end
  #declare LabelFontScale = LabelFontScale*0.9;
  #declare LabelHeight = 2*LabelFontScale;
  union {
    box {
      <-LabelWidth/2, -LabelHeight/2, 0>, <LabelWidth/2, 0, 0.1>
      pigment { color rgb <1, 1, 1> }
      finish { ambient 0 diffuse 1 }
    }
    box {
      <-LabelWidth/2, 0, 0>, <LabelWidth/2, LabelHeight/2, 0.1>
      pigment { color rgb <0, 0, 0> }
      finish { ambient 0 diffuse 1 }
    }
    text {
      ttf "c:\windows\fonts\courbd.ttf",
      LabelText1,
      0.1, 0
      translate <-strlen(LabelText1)*0.3, -0.6/2, -0.1>
      scale LabelFontScale
      translate LabelHeight/4*y
      pigment { color rgb <1, 1, 1> }
      finish { ambient 0 diffuse 1 }
    }
    text {
      ttf "c:\windows\fonts\courbd.ttf",
      LabelText2,
      0.1, 0
      translate <-strlen(LabelText2)*0.3, -0.6/2, -0.1>
      scale LabelFontScale
      translate -LabelHeight/4*y
      pigment { color rgb <0, 0, 0 > }
      finish { ambient 0 diffuse 1 }
    }
    translate <X, Y-1, -1.5> + ScenePos
  }
  #declare i = i + 1;
  #declare TextureNr = TextureNr + 1;
#end

camera {
   location <0, 5, -30>
   direction <0, 0,  1.35>
   look_at 5*y
   translate ScenePos
}

light_source { <0, 0, -1000> + ScenePos color rgb<0.658824, 0.658824, 0.658824> }

light_source {<150, 50, -200> + ScenePos color rgb<0.658824, 0.658824, 0.658824> }

plane { z, 1.1 pigment { color rgb <1,1,1> } hollow translate ScenePos}
